*cd "/Users/.../SPP_Replication/"

log using "models.log", replace

*** Figure 1: Development of usage of "I dissent" over time
use "dissentData.dta", clear
drop if term < 1937 | term > 2014
tab Idissent
pwcorr Idissent negemoC
egen prIdiss = mean(Idissent), by(term)
keep prIdiss term
duplicates drop 

twoway (line prIdiss term), xtick(1937(1)2014) xlab(1940(10)2010) graphregion(lcolor(black) lwidth(thick)) graphregion(fcolor(white)) ytitle(Proportion of Strong Dissents) xtitle(Term)


*** Table 1: Ranking Justices on Negativity
use "dissentData.dta", clear
gen oldJus = 0
replace oldJus = 1 if term < 1937
egen oldJus2 = max(oldJus), by(justiceName)
drop if oldJus2 == 1
drop if term > 2014
gen counter = 1
egen numDissents = sum(counter), by(justiceName)
egen totNegC = sum(negemoC), by(justiceName)
egen meanNegC = mean(negemoC), by(justiceName)
egen prIdiss = mean(Idissent), by(justiceName) 

keep justice author justiceName numDissents totNegC meanNegC prIdiss
duplicates drop
gsort -prIdiss
gen prIdissRank = _n
gsort -meanNegC
gen meanNegCRank = _n
gsort -numDissents
gen numDissRank = _n
gsort -totNegC
gen totNegCRank = _n

list author totNegC totNegCRank meanNegC meanNegCRank prIdiss prIdissRank numDissents 


*** Main Empirical Anlysis
use "dissentTermData.dta", clear

*** Table 2
** Model 0
meprobit nonneg_cite negemoC posemoC citeddistinct90  ,  || dissenter: || issueArea:

** Model 1
meprobit nonneg_cite negemoC posemoC citeddistinct90 citedIdissent firstPronC spec_factor logWC b4.dissVotes iddist issueAreaProp c.dissentAge##c.dissentAge##c.dissentAge ,  || dissenter: || issueArea:
estimates store mod1

** Model 2
meprobit nonneg_cite negemoC posemoC citeddistinct90I citedIdissent firstPronC spec_factor logWC b4.dissVotes iddist issueAreaProp c.dissentAge##c.dissentAge##c.dissentAge if issueB != 3,  || dissenter: || issueArea: 


*FN 16: Model 1 run on only data from the Warren Court forward
meprobit nonneg_cite negemoC posemoC citeddistinct90 spec_factor firstPronC citedIdissent logWC b4.dissVotes iddist issueAreaProp c.dissentAge##c.dissentAge##c.dissentAge if citingTerm > 1952,  || dissenter: || issueArea:


*** Generate predicted probabilities
estimates restore mod1
sum negemoC posemoC citeddistinct90 spec_factor firstPronC logWC iddist issueAreaProp dissentAge, detail
tab dissVotes
tab citedIdissent
sum dissentAge if nonneg_cite == 1, detail

** Figure2: Effect of Age of Dissent
*margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=(0(5)67)) predict(mu fixedonly)
*marginsplot, yscale(range(0 .025)) ytick(0(.001).025) ylab(0(.005).025) recast(line) plotopts(lcolor(black) lwidth(medium))  recastci(rarea) ciopts(fcolor(gs12) lcolor( gs12) ) ytitle(Predicted Probability of Citation) xtitle(Age of Dissent) title("") xsize(3) ysize(2.25) graphregion(lcolor(black) lwidth(thick)) graphregion(fcolor(white))  

* Baseline predicted prob. of citing a dissent
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=22)  predict(mu fixedonly)

* Baseline predicted prob. of citing a dissent that is 9 years old
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly)

** Figure 3, left panel: Negative Emotion
*margins, at(negemoC=(0(20)140) posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly)
*marginsplot, yscale(range(0 .02)) ytick(0(.025).02) ylab(0(.005).02)  xtick(0(20)140) xlab(0(20)140) recast(line) plotopts(lcolor(black) lwidth(medium))  recastci(rarea) ciopts(fcolor(gs12) lcolor( gs12) ) ytitle(Predicted Probability of Citation) xtitle(Negative Emotion Words)  title("") xsize(3) ysize(2.25) graphregion(lcolor(black) lwidth(thick)) graphregion(fcolor(white))  

** Figure 3, right panel: Distinctive Words Figure
*margins, at(negemoC=13 posemoC=19 citeddistinct90=(0(20)180) spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly)
*marginsplot, yscale(range(0 .02)) ytick(0(.025).02) ylab(0(.005).02)   xtick(0(20)180) xlab(0(20)180) recast(line) plotopts(lcolor(black) lwidth(medium))  recastci(rarea) ciopts(fcolor(gs12) lcolor( gs12) ) ytitle(Predicted Probability of Citation) xtitle(Distinctive Words)  title("") xsize(3) ysize(2.25) graphregion(lcolor(black) lwidth(thick)) graphregion(fcolor(white))  

*** Appendix A, Table 6: Change in predicted probability of citation when moving from high to low on each variable
estimates restore mod1
margins, at(negemoC=(5 29) posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=(7 40) citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=(7 39) spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=(0 1) logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=(3 15) citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor=(-.649 .299) firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=(6.328 7.898) dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=(4 3)  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=(4 2)  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=(4 1)  iddist=1.488 issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=(.578 2.849) issueAreaProp=.154 dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=(.073 .214) dissentAge=9)  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample
estimates restore mod1
margins, at(negemoC=13 posemoC=19 citeddistinct90=18 spec_factor= -0.278 firstPronC=7 citedIdissent=0 logWC=7.205 dissVotes=3  iddist=1.488 issueAreaProp=.154 dissentAge=(11 36))  predict(mu fixedonly) post contrast(atcontrast(ar._at)) noesample

log close
